@@ -5,8 +5,8 @@ SECRET_KEY = ""
 
 RS_HOST = "rs.qbox.me"
 RSF_HOST = "rsf.qbox.me"
-UP_HOST = "upload.qiniu.com"
-UP_HOST2 = "up.qbox.me"
+UP_HOST = "up.qiniu.com"
+UP_HOST2 = "upload.qbox.me"
 
 from . import __version__
 import platform
