@@ -177,17 +177,6 @@ class TestUp(unittest.TestCase):
         ret, err = io.put("", key, data, extra)
         assert "reqid" in err
 
-    def test_put_with_uphost2(self):
-        conf.UP_HOST = "api.qiniu.com"  # mistake up host
-        localfile = "%s" % __file__
-        key = "test_up2_%s" % r(9)
-
-        extra.check_crc = 1
-        ret, err = io.put_file(policy.token(), key, localfile, extra)
-        assert err is None
-        assert ret['key'] == key
-        conf.UP_HOST = "up.qiniu.com"
-
 
 class Test_get_file_crc32(unittest.TestCase):
 
